(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10039,        389]*)
(*NotebookOutlinePosition[     11225,        427]*)
(*  CellTagsIndexPosition[     11084,        419]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[
"Evolution Strategies\n\[LongDash] The Key Experiments "], "Title"],

Cell["\<\
Christian Jacob, jacob@cpsc.ucalgary.ca, May 1998 / February 2001 \
\[Copyright]\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Zig-Zagging after Darwin: Minimum Drag Configuration", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"Zigzagging"],

Cell["\<\
The following experiment was performed in 1964 at the Hermann-F\
\[ODoubleDot]ttinger-Institute in Berlin by Ingo Rechenberg, who was a \
student at the Technical University of Berlin.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Experiment setup", "Subsection"],

Cell["The experimental setup was as follows: ", "Text"],

Cell["\<\
Six board-shaped strips were flexibly connected at their \
longitudinal edges.\
\>", "ListSquare"],

Cell[TextData[{
  "The joints could be individually adjusted and fixed in angular intervals \
of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^o\)]],
  ", each joint allowing 51 steps.\nWith their five joints, the \
interconnected strips could assume ",
  Cell[BoxData[
      \(TraditionalForm\`51\^5 = 345\ 025\ 251\)]],
  " different configurations."
}], "ListSquare"]
}, Closed]],

Cell[CellGroupData[{

Cell["Objective", "Subsection"],

Cell[TextData[{
  "The objective is to develop a configuration having ",
  StyleBox["minimum drag",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["\<\
At the beginning of the experiment, the plate was folded into an \
irregular zig-zag shape.\
\>", "Text"],

Cell["\<\
As it was known beforehand that a flat plate satisfies this \
requirement, the solution to this experiment was self-evident.\
\>", "Text"],

Cell["\<\
The challenge lay in handling the rules of evolution such as if \
they were directions for technical experimentation.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Evolution Procedure", "Subsection"],

Cell["\<\
The procedure, free after Darwin, consists of four experimental \
steps:\
\>", "Text"],

Cell[TextData[{
  "1.\t",
  StyleBox["Evaluation",
    FontWeight->"Bold"],
  ": Drag measurement of the parent plate."
}], "ListNumbered"],

Cell[TextData[{
  "2.\t",
  StyleBox["Mutation",
    FontWeight->"Bold"],
  ": Random change of all joint angles by small amounts."
}], "ListNumbered"],

Cell[TextData[{
  "3.\t",
  StyleBox["Offspring Evaluation",
    FontWeight->"Bold"],
  ": Drag measurement of the mutated configuration."
}], "ListNumbered"],

Cell[TextData[{
  "4. ",
  StyleBox["Selection",
    FontWeight->"Bold"],
  ": Removal of the configuration with higher drag."
}], "ListNumbered"]
}, Closed]],

Cell[CellGroupData[{

Cell["Perfoming the Experiment", "Subsection"],

Cell[TextData[{
  "This experiment was performed in the summer of 1964 and was considered an \
\"Experimentum Crucis\" [",
  ButtonBox["Rechenberg, 1965",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Rechenberg 1965"},
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell["\<\
The key questions were whether, by using the basic mechanisms of \
biological evolution (mutation and selection only), a flat configuration of \
the plate could be obtained and how much time was required for it.\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsection"],

Cell["\<\
Sceptics anticipated that several million iterations would be \
necessary!\
\>", "Text"],

Cell[TextData[
"However, they were proved wrong: Already after 300 mutations the plate had \
assumed a form which, in a technical sense, is planar \[LongDash] considering \
that the drag of a very slightly curved plate is the same as that of an \
exactly flat plate."], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution of a Bent Pipe Coupling", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"Bent pipe"],

Cell["\<\
The evolution experiment described here was meant to be more \
convincing than the Experimentum Crucis for the drag configuration.\
\>", 
  "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Objective", "Subsection"],

Cell[TextData[{
  "The aim was to determine the shape of a ",
  Cell[BoxData[
      \(TraditionalForm\`90\^o\)]],
  " pipe coupling having the least possible friction losses."
}], "Text"],

Cell["\<\
The experiment involved the representation of the coupling by a \
plastic tube whose curvature could be altered at six locations by adjustable \
rods.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Performing the Experiment", "Subsection"],

Cell["\<\
The experiment started with a configuration in the form of a \
quarter circle.\
\>", "Text"],

Cell["\<\
The process of optimization required 300 mutations of the coupling \
geometry.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsection"],

Cell["\<\
Comparing the initial with the final configuration displays two \
unexpected features:\
\>", "Text"],

Cell["\<\
At the point of flow entry, the bend of the optimized coupling \
increases gradually.\
\>", "ListSquare"],

Cell["\<\
At the other end of the optimized coupling, a slight overswing of \
the curvature occurs.\
\>", "ListSquare"],

Cell["\<\
The optimized coupling resulted in a 9% reduction of the frictional \
losses.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Evolution of a Two-Phase Nozzle", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
  CellTags->"Two-phase nozzle"],

Cell["\<\
In 1968, the evolution strategists in Berlin was approached by \
industry with the request to optimize a two-phase jet nozzle:\
\>", "Text"],

Cell[TextData[StyleBox["Superheated steam was to be partially evaporated by \
the diminuation of pressure in an appropriately tapered nozzle, the expanding \
steam being a propellant for the remaining fluid.",
  FontSlant->"Plain"]], "Text",
  CellMargins->{{104, Inherited}, {Inherited, Inherited}},
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Objective", "Subsection"],

Cell["\<\
The problem was to obtain a maximum velocity for the fluid-steam \
mixture.\
\>", "Text"],

Cell["\<\
The juxtaposition of fluid and steam leads to extremely complex \
flow fields in the nozzle, which defy the determination of its most \
advantageous shape by pure mathematical analysis.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Experimental Setup", "Subsection"],

Cell["\<\
For this experiment, a boiler with a steam power of 5 tons per hour \
had to be operated at the Technical University of Berlin\
\>", "Text"],

Cell[TextData[{
  "Based on an idea of Hans-Paul Schwefel for an evolution strategic \
experiment, the nozzle was represented by a series of segments [",
  ButtonBox["Schwefel, 1968",
    ButtonData:>{
      FrontEnd`FileName[ {"..", "..", "IEC-Setup", "References.nb"}], 
      "Schwefel 1968"},
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell["\<\
A total of 330 compatible segments with conically shaped interior \
openings were prepared. \
\>", "Text"],

Cell[TextData[{
  "This allowed the assembly of potentially ",
  Cell[BoxData[
      \(TraditionalForm\`10\^60\)]],
  " different nozzle configurations without discontinuities in their \
contours."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Performing the Experiment", "Subsection"],

Cell["\<\
The initial configuration was an analytically derived Laval-type \
nozzle with an especially long convergent inlet section.\
\>", "Text"],

Cell["\<\
The continual exchange of segments by the experimental rules of \
Evolution Strategy produced a completely unexpected optimal \
configuration.\
\>", "Text"],

Cell["\<\
The efficiency was raised from 55% (parent) to nearly 80% \
(optimum).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsection"],

Cell["\<\
The strangely shaped bulges of the optimized nozzle attracted the \
attention of fluid dynamicists. Further experiments with an optimized nozzle \
made of special glass provided insight into the function of the bulges: They \
promote the formation of rotational flow which reduces the temperature \
gradient in the influx section and impedes the separation of the liquid and \
steam phases in the exit section.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{668, 500},
WindowMargins->{{75, Automatic}, {Automatic, 36}},
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[ParentDirectory[]], \
"IEC-Setup"}, "EvolvicaStyle.nb", CharacterEncoding -> "WindowsANSI"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Zigzagging"->{
    Cell[2044, 66, 60, 1, 55, "Subsection",
      CellTags->"Zigzagging"]},
  "Bent pipe"->{
    Cell[5564, 211, 59, 1, 55, "Subsection",
      CellTags->"Bent pipe"]},
  "Two-phase nozzle"->{
    Cell[7159, 286, 66, 1, 55, "Subsection",
      CellTags->"Two-phase nozzle"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Zigzagging", 10783, 406},
  {"Bent pipe", 10876, 409},
  {"Two-phase nozzle", 10976, 412}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 82, 1, 139, "Title"],
Cell[1812, 55, 111, 3, 62, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1948, 62, 71, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[2044, 66, 60, 1, 55, "Subsection",
  CellTags->"Zigzagging"],
Cell[2107, 69, 208, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2352, 78, 38, 0, 55, "Subsection"],
Cell[2393, 80, 55, 0, 26, "Text"],
Cell[2451, 82, 108, 3, 26, "ListSquare"],
Cell[2562, 87, 371, 10, 80, "ListSquare"]
}, Closed]],

Cell[CellGroupData[{
Cell[2970, 102, 31, 0, 55, "Subsection"],
Cell[3004, 104, 142, 5, 27, "Text"],
Cell[3149, 111, 115, 3, 26, "Text"],
Cell[3267, 116, 148, 3, 44, "Text"],
Cell[3418, 121, 141, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3596, 129, 45, 0, 55, "Subsection"],
Cell[3644, 131, 96, 3, 26, "Text"],
Cell[3743, 136, 139, 5, 27, "ListNumbered"],
Cell[3885, 143, 151, 5, 27, "ListNumbered"],
Cell[4039, 150, 158, 5, 27, "ListNumbered"],
Cell[4200, 157, 146, 5, 27, "ListNumbered"]
}, Closed]],

Cell[CellGroupData[{
Cell[4383, 167, 46, 0, 55, "Subsection"],
Cell[4432, 169, 319, 9, 44, "Text"],
Cell[4754, 180, 237, 5, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5028, 190, 29, 0, 55, "Subsection"],
Cell[5060, 192, 98, 3, 26, "Text"],
Cell[5161, 197, 277, 4, 62, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5487, 207, 52, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[5564, 211, 59, 1, 55, "Subsection",
  CellTags->"Bent pipe"],
Cell[5626, 214, 157, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5820, 223, 31, 0, 55, "Subsection"],
Cell[5854, 225, 187, 5, 44, "Text"],
Cell[6044, 232, 174, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6255, 241, 47, 0, 55, "Subsection"],
Cell[6305, 243, 102, 3, 26, "Text"],
Cell[6410, 248, 102, 3, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6549, 256, 29, 0, 55, "Subsection"],
Cell[6581, 258, 110, 3, 26, "Text"],
Cell[6694, 263, 115, 3, 44, "ListSquare"],
Cell[6812, 268, 119, 3, 44, "ListSquare"],
Cell[6934, 273, 101, 3, 26, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7084, 282, 50, 0, 62, "Section"],

Cell[CellGroupData[{
Cell[7159, 286, 66, 1, 55, "Subsection",
  CellTags->"Two-phase nozzle"],
Cell[7228, 289, 150, 3, 44, "Text"],
Cell[7381, 294, 323, 5, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7741, 304, 31, 0, 55, "Subsection"],
Cell[7775, 306, 99, 3, 26, "Text"],
Cell[7877, 311, 209, 4, 62, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8123, 320, 40, 0, 55, "Subsection"],
Cell[8166, 322, 150, 3, 44, "Text"],
Cell[8319, 327, 346, 9, 44, "Text"],
Cell[8668, 338, 116, 3, 44, "Text"],
Cell[8787, 343, 209, 6, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9033, 354, 47, 0, 55, "Subsection"],
Cell[9083, 356, 147, 3, 44, "Text"],
Cell[9233, 361, 166, 4, 44, "Text"],
Cell[9402, 367, 94, 3, 26, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9533, 375, 29, 0, 55, "Subsection"],
Cell[9565, 377, 434, 7, 98, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

